<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation>Inicieu sessió amb l&apos;identificador del Deepin.</translation>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation>Cal iniciar sessió per continuar amb les operacions posteriors.</translation>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation>Heu fet massa peticions. Si us plau, torneu-ho a provar més tard.</translation>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation>Cal iniciar sessió per continuar les operacions posteriors.</translation>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation>Error de xarxa, proveu-ho més tard.</translation>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>Unlogged</source>
        <translation>Fora de la sessió</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Favorits</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Els meus comentaris</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>Surt de la sessió</translation>
    </message>
    <message>
        <source>Sign in</source>
        <translation>Inicieu la sessió</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1 visualitzacions</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suggeriments</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No als favorits</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorits</translation>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation>Cancel·la&apos;n la urgència</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Urgent</translation>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>Pròximament</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>Resposta oficial</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipus:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Tot</translation>
    </message>
    <message>
        <source>Bug</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suggeriments</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versió:</translation>
    </message>
    <message>
        <source>Sort:</source>
        <translation>Classificació:</translation>
    </message>
    <message>
        <source>Newest</source>
        <translation>El més nou</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Urgent</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>Comunicació</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Comenteu i compartiu aquí</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Informe d&apos;error</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Informeu d&apos;errors que trobeu</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suggeriments</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Envieu suggeriments</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Recursos</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Qüestionari</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Uniu-vos</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Proves internes</translation>
    </message>
    <message>
        <source>Global Translation</source>
        <translation>Traducció global</translation>
    </message>
    <message>
        <source>Community News</source>
        <translation>Notícies de la comunitat</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>No more items</source>
        <translation>No hi ha més elements.</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Missatges</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>Qüestionaris</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>Obre a l&apos;inici del sistema.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Inici del Deepin</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation>Inicieu sessió ràpida als fòrums, envieu suggeriments i informeu d&apos;errors.</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Encara no hi ha missatges.</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 missatges</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Marca&apos;ls tots com a llegits</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Mostra&apos;n més</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation>Error de xarxa, proveu-ho més tard</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Actualitza</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Inici del Deepin</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>Encara no hi ha qüestionaris.</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>Caducat: %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>Completa</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>Pendent</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation>Reproducció</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmat</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>Respost</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>Resolt</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>En avaluació</translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>Acceptat</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Completat</translation>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation>El problema no s&apos;ha processat i no es mostrarà a la llista pública.</translation>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation>Actualment no se&apos;n pot identificar la causa; calen un seguiment i una investigació contínues.</translation>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation>El problema s&apos;ha reproduït i se n&apos;ha identificat la causa.</translation>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation>El problema no és un error o té una naturalesa diferent.</translation>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation>El problema s&apos;ha resolt i se n&apos;espera l&apos;alliberament formal.</translation>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation>El requisit no s&apos;ha processat i no es mostrarà a la llista pública.</translation>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation>El problema ha estat reconegut i s&apos;està avaluant internament.</translation>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation>Inclòs en els plans per a un llançament futur</translation>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation>El requisit no s&apos;accepta o no es pot atendre.</translation>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation>La feina de desenvolupament s&apos;ha acabat. Se n&apos;espera l&apos;alliberament formal.</translation>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation>No es pot afegir una captura de pantalla.</translation>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation>La mida del fitxer d&apos;imatge ha de ser inferior a 1 MB.</translation>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation>El format de fitxer d&apos;imatge no és compatible per a la càrrega.</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation>[Estat actual del producte]:
[Producte desitjat]:</translation>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation>[Condicions prèvies]:
[Passos de reproductibilitat]:
[Resultats esperats]:
[Resultats reals]:</translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>Envieu comentaris</translation>
    </message>
    <message>
        <source>Type：</source>
        <translation>Tipus:</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suggeriments</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Informe d&apos;error</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation>Títol:</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation>Si us plau, proporcioneu una descripció breu del problema.</translation>
    </message>
    <message>
        <source>Content：</source>
        <translation>Contingut:</translation>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation>No afegiu diversos problemes en un sol comentari.</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation>No ompliu diversos requisits en un sol comentari.</translation>
    </message>
    <message>
        <source>Email：</source>
        <translation>Adreça electrònica:</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation>Si us plau, escriviu l&apos;adreça electrònica.</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>Versió del sistema:</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>Informació del dispositiu:</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation>Carrega la &lt;a href=&apos;home://sysinfo&apos;&gt;informació del dispositiu&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>Captures de pantalla:</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Fitxers d&apos;imatge</translation>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation>Arrossegueu i deixeu-hi anar fitxers o cliqueu als botons per afegir-hi imatges, fins a tres.</translation>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation>Segur que voleu sortir de l&apos;enviament de comentaris?</translation>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation>El contingut del comentari no es desarà.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>Envia</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation>No es poden enviar comentaris.</translation>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation>Si us plau, proporcioneu el títol i el contingut del comentari.</translation>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation>Si us plau, proporcioneu el títol i el contingut del comentari.</translation>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation>Si us plau, proporcioneu el contingut del comentari.</translation>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation>S&apos;ha introduït una adreça de correu electrònic incorrecta.</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>Informació del dispositiu</translation>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation>Centre d&apos;informació de retorn</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Els meus comentaris</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Favorits</translation>
    </message>
    <message>
        <source>My Urged</source>
        <translation>Urgències</translation>
    </message>
</context>
</TS>